Skip to contents

Shows the degrees of the different edge types in the GeneWalk network. Lack of PPI interactions for example will make it difficult for the method to identify patterns.

Usage

check_degree_distribution(object)

Arguments

object

The GeneWalk class, please see GeneWalk().