Skip to contents

Get the full GW data stored in the class

Usage

get_gw_data(x)

# S3 method for class 'DataBuilder'
get_gw_data(x)

Arguments

x

An object from which to extract the genewalk data.

Value

A data.table with the full data stored in the class.