GeneWalk
GeneWalk.RdClass that stores keeps all of the important data for the Gene Walk algorithm, see Ietswaart, et al. The class can be subsequently used for to apply the Gene Walk algorithm.
Arguments
- graph_dt
A data.table with the graph information. Needs to have the columns
"from","to"and"type"; type must include"hierarchy"for the pathways,"interaction"for interactions and"part_of"for gene/pathway interactions, and optionally a weight.- gene_to_pathway_dt
A data.table with the gene to pathway information. Needs to have
"from"(gene) and"to"(pathway).- gene_ids
String. The "bag of genes" you are testing.
- pathway_ids
String. The pathways represented in the network.
Properties
- graph_dt
A data.table that contains the initial graph.
- gene_to_pathway_dt
A data.table that contains the gene to pathway connections.
- gene_ids
The genes represented in your gene walk list.
- pathway_ids
The pathways represented in your gene walk network.
- embds
The initial embedding matrices generated by node2vec on top of the graph. Depends on the n_graph parameter you choose.
- permuted_embd
A list containing cosine distances of permuted graphs..
- stats
A data.table containing the information on the statistical testing across the permutations.
- params
A list in which used parameters will be stored.