Check the degree across different node types
check_degree_distribution.RdShows the degrees of the different edge types in the GeneWalk network. Lack of PPI interactions for example will make it difficult for the method to identify patterns.
Arguments
- object
The
GeneWalkclass, please seeGeneWalk().