get_gw_data.Rd
Get the full GW data stored in the class
get_gw_data(x) # S3 method for class 'DataBuilder' get_gw_data(x)
An object from which to extract the genewalk data.
A data.table with the full data stored in the class.