Plot similarity distributions
plot_similarities.RdPlots the cosine similarity distributions of the permuted embeddings alongside the actual values as density histograms.
plot_similarities.RdPlots the cosine similarity distributions of the permuted embeddings alongside the actual values as density histograms.